# CREATED : 20130508


def closeIcon():
    """ *Get close icon. The generic close icon for dismissing content like modals and alerts.*

    **Key Arguments:**

    **Return:**
        - ``closeIcon`` -- the closeIcon """

    closeIcon = """<button class="close">&times;</button>"""
    return closeIcon
